//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/SampleDesigner/SampleView.h
//! @brief     Defines class SampleView
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H
#define BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H

#include <QMainWindow>

class DocksController;
class ProjectDocument;
class SampleToolBar;
class RealSpacePanel;
class QItemSelection;
class SessionItem;

class SampleView : public QMainWindow {
    Q_OBJECT
public:
    enum ESubWindows { TOOLBOX, SAMPLE_TREE, PROPERTY_EDITOR, INFO, REALSPACEPANEL, SAMPLE_LIST };

    SampleView(QWidget* parent, ProjectDocument* document, bool initAsLayerOrientedEditor = true);

    void toggleRealSpaceView();
    void fillViewMenu(QMenu* menu);

private:
    void resetLayout();
    void initNetOrientedEditor();
    void initLayerOrientedEditor();
    void deleteEditor();
    void updateFunctionalities();
    void onSampleTreeViewSelectionChanged(const QItemSelection& selected, const QItemSelection&);

    //! Show the item in the real space view
    //!
    //! If the real space view is not visible at the moment, it will be shown.
    void onRequestViewInRealSpace(SessionItem* itemToView);

    DocksController* m_docks = nullptr;
    ProjectDocument* m_document = nullptr;
    SampleToolBar* m_toolBar = nullptr;
    RealSpacePanel* m_realSpacePanel = nullptr;
    bool m_useLayerOrientedEditor = false;
};

#endif // BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SAMPLEVIEW_H
